@@ -80,8 +80,8 @@
 #' also available.
 #' 
 #' The argument \code{init.type} allows the user to specify an intialization
-#' method.  The default uses collapsed gibbs sampling for the LDA model.  The
-#' choice \code{"Spectral"} provides a deterministic inialization using the
+#' method. The default 
+#' choice, \code{"Spectral"}, provides a deterministic inialization using the
 #' spectral algorithm given in Arora et al 2014.  See Roberts, Stewart and
 #' Tingley (2016) for details and a comparison of different approaches.
 #' Particularly when the number of documents is relatively large we highly
@@ -92,7 +92,13 @@
 #' frequent 10000 terms in creating the initialization.  This may case the 
 #' first step of the algorithm to have a very bad value of the objective function
 #' but it should quickly stabilize into a good place.  You can tweak the exact 
-#' number where this kicks in with the \code{maxV} argument inside control.
+#' number where this kicks in with the \code{maxV} argument inside control. There
+#' appear to be some cases where numerical instability in the Spectral algorithm
+#' can cause differences across machines (particularly Windows machines for some reason).
+#' It should always give exactly the same answer for a given machine but if you are
+#' seeing different answers on different machines, see https://github.com/bstewart/stm/issues/133
+#' for a longer explanation.  The other option \code{"LDA"} which uses a few passes
+#' of a Gibbs sampler is perfectly reproducible across machines as long as the seed is set.
 #' 
 #' Specifying an integer greater than 1 for the argument \code{ngroups} causes
 #' the corpus to be broken into the specified number of groups.  Global updates
@@ -209,6 +215,9 @@
 #' number of words to be used in the initialization.  It uses the most frequent words
 #' first and then they are reintroduced following initialization.  This allows spectral
 #' to be used with a large V.}
+#' \item{\code{recoverEG}}{Set to code{TRUE} by default.  If set to \code{FALSE}
+#'  will solve the recovery problem in the Spectral algorithm using a downhill simplex
+#'  method.  See https://github.com/bstewart/stm/issues/133 for more discussion.}
 #' \item{\code{allow.neg.change}}{A logical indicating whether the algorithm is allowed
 #' to declare convergence when the change in the bound has become negative. 
 #' Defaults to \code{TRUE}.  Set to \code{FALSE} to keep the algorithm from converging
@@ -227,6 +236,13 @@
 #' is a K by V matrix containing the logged word probability conditional on the topic.  If you use this
 #' option we recommend that you use \code{max.em.its=0} with the model initialization set to random, inspect
 #' the returned form of \code{stmobj$beta$logbeta} and ensure that it matches your format.}
+#' \item{\code{tSNE_init.dims}}{The K=0 spectral setting uses tSNE to create a low-dimensional
+#' projection of the vocab co-occurence matrix.  tSNE starts with a PCA projection as an initialization.
+#' We actually do the projection outside the tSNE code so we can use a randomized projection approach.
+#' We use the 50 dimensional default of the \pkg{rtsne} package.  That can be changed here.}
+#' \item{\code{tSNE_perplexity}}{The \code{Rtsne} function in the \pkg{rtsne} package uses a perplexity
+#' parameter.  This defaults to 30 and can throw an error when too high.  \code{stm} will automatically lower
+#' the parameter for you until it works, but it can also be directly set here.}
 #' }
 #' 
 #' 
@@ -552,7 +568,8 @@ stm <- function(documents, vocab, K,
                             enet=1,nlambda=250, lambda.min.ratio=.001, ic.k=2,
                             maxit=1e4),
                    init=list(mode=init.type, nits=50, burnin=25, alpha=(50/K), eta=.01,
-                             s=.05, p=3000, d.group.size=2000, recoverEG=TRUE), 
+                             s=.05, p=3000, d.group.size=2000, recoverEG=TRUE,
+                             tSNE_init.dims=50, tSNE_perplexity=30), 
                    seed=seed,
                    ngroups=ngroups)
   if(init.type=="Spectral" & V > 10000) {
@@ -593,7 +610,7 @@ stm <- function(documents, vocab, K,
                   "nits", "burnin", "alpha", "eta", "contrast",
                   "rp.s", "rp.p", "rp.d.group.size", "SpectralRP",
                   "recoverEG", "maxV", "gamma.maxits", "allow.neg.change",
-                  "custom.beta")
+                  "custom.beta", "tSNE_init.dims", "tSNE_perplexity")
   if (length(control)) {
     indx <- pmatch(names(control), legalargs, nomatch=0L)
     if (any(indx==0L))
@@ -626,6 +643,8 @@ stm <- function(documents, vocab, K,
         settings$init$maxV <- control[[i]]
         if(settings$init$maxV > V) stop("maxV cannot be larger than the vocabulary")
       }
+      if(i=="tSNE_init.dims" && control[[i]]) settings$init$tSNE_init.dims <- control[[i]]
+      if(i=="tSNE_perplexity" && control[[i]]) settings$init$tSNE_perplexity <- control[[i]]
       if(i=="gamma.maxits") settings$gamma$maxits <- control[[i]]
       if(i=="allow.neg.change") settings$convergence$allow.neg.change <- control[[i]]
       if(i=="custom.beta") {
